@@ -41,18 +41,22 @@ class Test(unittest.TestCase):
         #Remove audit mode from ntpd profile and check if it was correctly removed
         subprocess.check_output('%s ./../aa-audit -d ./profiles -r %s'%(python_interpreter, test_path), shell=True)
 
-        self.assertEqual(apparmor.get_profile_flags(local_profilename, test_path), None, 'Complain flag could not be removed in profile %s'%local_profilename)
+        self.assertEqual(apparmor.get_profile_flags(local_profilename, test_path), None, 'Audit flag could not be removed in profile %s'%local_profilename)
 
 
     def test_complain(self):
         #Set ntpd profile to complain mode and check if it was correctly set
         subprocess.check_output('%s ./../aa-complain -d ./profiles %s'%(python_interpreter, test_path), shell=True)
+       
+        # "manually" create a force-complain symlink (will be deleted by aa-enforce later)
+        os.mkdir('./profiles/force-complain')
+        os.symlink(local_profilename, './profiles/force-complain/%s'%os.path.basename(local_profilename) )
 
         self.assertEqual(os.path.islink('./profiles/force-complain/%s'%os.path.basename(local_profilename)), True, 'Failed to create a symlink for %s in force-complain'%local_profilename)
         self.assertEqual(apparmor.get_profile_flags(local_profilename, test_path), 'complain', 'Complain flag could not be set in profile %s'%local_profilename)
 
         #Set ntpd profile to enforce mode and check if it was correctly set
-        subprocess.check_output('%s ./../aa-complain -d ./profiles -r %s'%(python_interpreter, test_path), shell=True)
+        subprocess.check_output('%s ./../aa-enforce -d ./profiles %s'%(python_interpreter, test_path), shell=True)
 
         self.assertEqual(os.path.islink('./profiles/force-complain/%s'%os.path.basename(local_profilename)), False, 'Failed to remove symlink for %s from force-complain'%local_profilename)
         self.assertEqual(os.path.islink('./profiles/disable/%s'%os.path.basename(local_profilename)), False, 'Failed to remove symlink for %s from disable'%local_profilename)
@@ -61,12 +65,14 @@ class Test(unittest.TestCase):
         # Set audit flag and then complain flag in a profile
         subprocess.check_output('%s ./../aa-audit -d ./profiles %s'%(python_interpreter, test_path), shell=True)
         subprocess.check_output('%s ./../aa-complain -d ./profiles %s'%(python_interpreter, test_path), shell=True)
+        # "manually" create a force-complain symlink (will be deleted by aa-enforce later)
+        os.symlink(local_profilename, './profiles/force-complain/%s'%os.path.basename(local_profilename) )
 
         self.assertEqual(os.path.islink('./profiles/force-complain/%s'%os.path.basename(local_profilename)), True, 'Failed to create a symlink for %s in force-complain'%local_profilename)
         self.assertEqual(apparmor.get_profile_flags(local_profilename, test_path), 'audit,complain', 'Complain flag could not be set in profile %s'%local_profilename)
 
         #Remove complain flag first i.e. set to enforce mode
-        subprocess.check_output('%s ./../aa-complain -d ./profiles -r %s'%(python_interpreter, test_path), shell=True)
+        subprocess.check_output('%s ./../aa-enforce -d ./profiles %s'%(python_interpreter, test_path), shell=True)
 
         self.assertEqual(os.path.islink('./profiles/force-complain/%s'%os.path.basename(local_profilename)), False, 'Failed to remove symlink for %s from force-complain'%local_profilename)
         self.assertEqual(os.path.islink('./profiles/disable/%s'%os.path.basename(local_profilename)), False, 'Failed to remove symlink for %s from disable'%local_profilename)
@@ -133,7 +139,7 @@ if __name__ == "__main__":
 
     #copy the local profiles to the test directory
     #Should be the set of cleanprofile
-    shutil.copytree('/etc/apparmor.d', './profiles', symlinks=True)
+    shutil.copytree('../../profiles/apparmor.d/', './profiles', symlinks=True)
 
     apparmor.profile_dir = './profiles'
 
